==> apache-qpid-broker-j-8.0.6-src.tar.gz: apache-qpid-broker-j-8.0.6-src/perftests/src/main/java/org/apache/qpid/disttest/client/property/PropertyValueFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.qpid.disttest.client.property;

import org.apache.qpid.disttest.DistributedTestException;

/**
 * Creates property value instances using given alias (type) value.
 */
public class PropertyValueFactory
{
    public PropertyValue createPropertyValue(String type)
    {
        try
        {
            return getPropertyValueClass(type).newInstance();
        }
        catch(Exception e)
        {
            throw new DistributedTestException("Unable to create a generator for a type:" + type, e);
        }
    }

    public Class<PropertyValue> getPropertyValueClass(String type) throws ClassNotFoundException
    {
        String className = "org.apache.qpid.disttest.client.property."
                           + Character.toTitleCase(type.charAt(0))
                           + type.substring(1)
                           + "PropertyValue";
        return (Class<PropertyValue>) Class.forName(className);
    }
}

==> apache-qpid-broker-j-10.0.1-src.tar.gz: apache-qpid-broker-j-10.0.1-src/perftests/src/main/java/org/apache/qpid/disttest/client/property/PropertyValueFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.qpid.disttest.client.property;

import org.apache.qpid.disttest.DistributedTestException;

/**
 * Creates property value instances using given alias (type) value.
 */
public class PropertyValueFactory
{
    public PropertyValue createPropertyValue(String type)
    {
        try
        {
            return getPropertyValueClass(type).getDeclaredConstructor().newInstance();
        }
        catch (Exception e)
        {
            throw new DistributedTestException("Unable to create a generator for a type:" + type, e);
        }
    }

    public Class<PropertyValue> getPropertyValueClass(String type) throws ClassNotFoundException
    {
        String className = "org.apache.qpid.disttest.client.property."
                           + Character.toTitleCase(type.charAt(0))
                           + type.substring(1)
                           + "PropertyValue";
        return (Class<PropertyValue>) Class.forName(className);
    }
}
